==> elgg-1.11.0.zip: elgg-1.11.0/mod/file/languages/da.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Filer",
	'file:user' => "%s's filer",
	'file:friends' => "Venners filer",
	'file:all' => "Alle filer",
	'file:edit' => "Rediger fil",
	'file:more' => "Flere filer",
	'file:list' => "Liste",
	'file:group' => "Gruppe filer",
	'file:gallery' => "Galleri",
	'file:gallery_list' => "Vis som liste eller galleri",
	'file:num_files' => "Antal viste filer",
	'file:user:gallery'=>'Se %s galleri',
	'file:upload' => "Upload en fil",
	'file:replace' => 'Erstat fil indhold (lad være tom for ikke at ændre i fil)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Venner'",

	'file:add' => 'Upload en fil',

	'file:file' => "Fil",

	'file:list:list' => 'Switch to the list view',
	'file:list:gallery' => 'Switch to the gallery view',

	'file:types' => "Tilføjede filtyper",

	'file:type:' => 'Filer',
	'file:type:all' => "Alle filer",
	'file:type:video' => "Videoer",
	'file:type:document' => "Dokumenter",
	'file:type:audio' => "Lyd",
	'file:type:image' => "Billeder",
	'file:type:general' => "Andre",

	'file:user:type:video' => "%s's videoer",
	'file:user:type:document' => "%s's dokumenter",
	'file:user:type:audio' => "%s's lyd",
	'file:user:type:image' => "%s's billeder",
	'file:user:type:general' => "%s's generelle filer",

	'file:friends:type:video' => "Dine venners videoer",
	'file:friends:type:document' => "Dine venners dokumenter",
	'file:friends:type:audio' => "Dine venners lyd",
	'file:friends:type:image' => "Dine venners billeder",
	'file:friends:type:general' => "Dine venners generelle filer",

	'file:widget' => "Fil widget",
	'file:widget:description' => "Fremvis dine seneste filer",

	'groups:enablefiles' => 'Aktiver gruppefiler',

	'file:delete:confirm' => "Er du sikker på, at du vil slette denne fil?",

	'file:tagcloud' => "Tag cloud",

	'file:display:number' => "Antal viste filer",

	'river:create:object:file' => '%s tilføjede filen %s',
	'river:comment:object:file' => '%s kommenterede filen %s',

	'item:object:file' => 'Filer',

	'file:notify:summary' => 'Ny fil kaldt %s',
	'file:notify:subject' => 'Ny fil: %s',
	'file:notify:body' =>
'%s har uploadet en ny fil: %s

%s

See og kommenter på filen:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Din fil blev gemt.",
	'file:deleted' => "Din fil blev slettet.",

	/**
	 * Error messages
	 */

	'file:none' => "Vi kan ikke finde nogle filer i øjeblikket",
	'file:uploadfailed' => "Beklager, vi kunne ikke gemme din fil.",
	'file:downloadfailed' => "Beklager, denne fil er ikke til rådighed lige nu.",
	'file:deletefailed' => "Din fil kunne ikke slettes.",
	'file:noaccess' => "Du har ikke tilladelse ti at ændre denne fil",
	'file:nofile' => "Du skal vælge en fil",
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/file/languages/da.php <==
<?php
return array(

	'item:object:file' => 'Filer',
	'collection:object:file' => 'Files',
	'collection:object:file:all' => "All site files",
	'collection:object:file:owner' => "%s's files",
	'collection:object:file:friends' => "Friends' files",
	'collection:object:file:group' => "Group files",
	'add:object:file' => "Upload a file",
	'edit:object:file' => "Edit file",

	'file:more' => "Flere filer",
	'file:list' => "Liste",

	'file:num_files' => "Antal viste filer",
	'file:replace' => 'Erstat fil indhold (lad være tom for ikke at ændre i fil)',
	'file:list:title' => "%s's %s %s",
	'file:title:friends' => "Venner'",

	'file:file' => "Fil",

	'file:list:list' => 'Switch to the list view',
	'file:list:gallery' => 'Switch to the gallery view',

	'file:types' => "Tilføjede filtyper",

	'file:type:' => 'Filer',
	'file:type:all' => "Alle filer",
	'file:type:video' => "Videoer",
	'file:type:document' => "Dokumenter",
	'file:type:audio' => "Lyd",
	'file:type:image' => "Billeder",
	'file:type:general' => "Andre",

	'file:user:type:video' => "%s's videoer",
	'file:user:type:document' => "%s's dokumenter",
	'file:user:type:audio' => "%s's lyd",
	'file:user:type:image' => "%s's billeder",
	'file:user:type:general' => "%s's generelle filer",

	'file:friends:type:video' => "Dine venners videoer",
	'file:friends:type:document' => "Dine venners dokumenter",
	'file:friends:type:audio' => "Dine venners lyd",
	'file:friends:type:image' => "Dine venners billeder",
	'file:friends:type:general' => "Dine venners generelle filer",

	'widgets:filerepo:name' => "File widget",
	'widgets:filerepo:description' => "Showcase your latest files",

	'groups:tool:file' => 'Enable group files',

	'river:object:file:create' => '%s uploaded the file %s',
	'river:object:file:comment' => '%s commented on the file %s',

	'file:notify:summary' => 'Ny fil kaldt %s',
	'file:notify:subject' => 'Ny fil: %s',
	'file:notify:body' => '%s uploaded a new file: %s

%s

View and comment on the file:
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "The file was successfully saved.",
	'entity:delete:object:file:success' => "The file was successfully deleted.",

	/**
	 * Error messages
	 */

	'file:none' => "Vi kan ikke finde nogle filer i øjeblikket",
	'file:uploadfailed' => "Beklager, vi kunne ikke gemme din fil.",
	'file:noaccess' => "Du har ikke tilladelse ti at ændre denne fil",
	'file:cannotload' => "There was an error uploading the file",
);
